Use Case:  Update Existing Content
==================================

Actor
-----

Content Creator

Assumptions
-----------

Content Creator has logged into the CMF (see :doc:`LoginAsMember`).

Procedure
---------

1. Navigate to a piece of content you have the permissions to modify.

   To retrieve a list of the content you have authored, see
   :doc:`ViewMyContent`

2. After selecting the piece of content you wish to update, select 'Edit'
   from the actions box.

3. The 'Edit' link will take you to the edit form for your
   particular piece of content you wish to edit:

   * 'Body Textarea/File Upload' edit form (Documents)

   * 'Lead-in/Body' edit form (News Item)

   * 'File Upload' edit form (Files, Images)

   * 'Simple' edit form (Link, Favorite, Event)

   Enter the changes you wish to make to the content in the form or browse to
   changed version of the content on your filesystem as appropriate.

4. Click the change button. The system will save your changes, and display a
   change notification on the edit form confirming that the change has taken
   place.

5. To view your changes, click the 'View' link from the actions box and view
   your content with the changes in place.
